@@ -21,7 +21,7 @@ def createCodeBuildAction(self, codebuild_action_name, codebuild_input_artifact,
         project=codebuild.PipelineProject(
             self, codebuild_action_name,
             project_name=codebuild_action_name,
-            role=codebuild_role,
+            # role=codebuild_role,
             environment=codebuild.BuildEnvironment(
                 privileged=True
             ), 
